package com.shiyanlou.listener;

import com.shiyanlou.dao.entity.Admin;
import com.shiyanlou.dao.entity.Resource;
import com.shiyanlou.dao.entity.Role;
import com.shiyanlou.dao.repository.AdminRepository;
import com.shiyanlou.dao.repository.ResourceRepository;
import com.shiyanlou.dao.repository.RoleRepository;
import org.springframework.context.ApplicationContext;
import org.springframework.data.domain.Example;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.web.context.support.WebApplicationContextUtils;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import java.util.*;

/**
 * @ClassName InitListener
 * @Description 系统初始化的监听器
 * @Modify ...
 */
public class InitListener implements ServletContextListener {


    @Override
    public void contextInitialized(ServletContextEvent sce) {

        ServletContext sc = sce.getServletContext();
        ApplicationContext context = WebApplicationContextUtils.getWebApplicationContext(sc);
        ResourceRepository resourceRepository = context.getBean(ResourceRepository.class);
        RoleRepository roleRepository = context.getBean(RoleRepository.class);
        AdminRepository adminRepository = context.getBean(AdminRepository.class);
        PasswordEncoder passwordEncoder = context.getBean(PasswordEncoder.class);

        // 保存权限数据
        Resource menu, menu1, menu2;

        //==========================控制台=====================
        //一级权限
        menu = new Resource("控制台", null, new HashSet<String>() {{
            add("/index");
            add("/u/me");
        }});
        resourceRepository.saveAndFlush(menu);

        //==========================账号管理=====================
        //一级权限
        menu = new Resource("账号管理", null, null);
        resourceRepository.saveAndFlush(menu);
        //二级权限
        menu1 = new Resource("管理员管理", menu, new HashSet<String>() {{
            add("/admin");
            add("/admin/save");
        }});
        menu2 = new Resource("权限组管理", menu, new HashSet<String>() {{
            add("/role");
            add("/role/save");
        }});
        resourceRepository.saveAndFlush(menu1);
        resourceRepository.saveAndFlush(menu2);


        // 保存角色数据
        List<Resource> resources = resourceRepository.findAll();

        Role role = new Role();
        role.setName("超级管理员");
        role.setDescription("权限测试");
        role.setResources(resources);
        roleRepository.saveAndFlush(role);

        // 保存用户数据
        Role example = new Role();
        example.setName("超级管理员");

        List<Role> roleList = roleRepository.findAll(Example.of(example));
        Admin admin1 = new Admin();
        admin1.setUsername("admin");
        admin1.setName("花木兰");
        admin1.setNickName("花木兰233");
        admin1.setPassword(passwordEncoder.encode("123456"));
        if (roleList.size() > 0) {
            admin1.setRoles(new ArrayList<>(Arrays.asList(roleList.get(0))));
        }
        adminRepository.saveAndFlush(admin1);

        Admin admin2 = new Admin();
        admin2.setUsername("user");
        admin2.setName("小明");
        admin2.setNickName("小明233");
        admin2.setPassword(passwordEncoder.encode("123456"));
        adminRepository.saveAndFlush(admin2);
    }

    @Override
    public void contextDestroyed(ServletContextEvent servletContextEvent) {

    }
}