package com.shiyanlou.core.authentication.mobile;

import com.shiyanlou.core.authentication.ShiyanlouUserDetailsService;
import lombok.Data;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.InternalAuthenticationServiceException;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;

/**
 * 功能描述 :短信处理器，查询用户信息，成功存放到已认证token
 */
@Data
public class SmsCodeAuthenticationProvider implements AuthenticationProvider {

    private UserDetailsService userDetailsService;

    @Override
    public Authentication authenticate(Authentication authentication) throws AuthenticationException {

        SmsCodeAuthenticationToken authenticationToken = (SmsCodeAuthenticationToken) authentication;

        if (userDetailsService instanceof ShiyanlouUserDetailsService) {

            ShiyanlouUserDetailsService shiyanlouUserDetailsService = (ShiyanlouUserDetailsService) userDetailsService;

            UserDetails user = shiyanlouUserDetailsService.loadUserByMobile((String) authenticationToken.getPrincipal());

            if (user == null) {
                throw new InternalAuthenticationServiceException("无法获取用户信息");
            }

            SmsCodeAuthenticationToken authenticationResult = new SmsCodeAuthenticationToken(user, user.getAuthorities());
            //需要把未认证中的一些信息copy到已认证的token中
            authenticationResult.setDetails(authenticationToken.getDetails());

            return authenticationResult;

        } else {
            throw new InternalAuthenticationServiceException("请实现ShiyanlouUserDetailsService#loadUserByMobile方法");
        }

    }

    @Override
    public boolean supports(Class<?> authentication) {
        return SmsCodeAuthenticationToken.class.isAssignableFrom(authentication);
    }

}